@@ -34,7 +34,7 @@ def data_wrapper(data):
             "dataSource": [{"提示信息": "服务器数据出现错误请联系管理员"}],
         }
 
-    logger.info("data into json str...")
+    # logger.info("data into json str...")
     res = {}
     df = data["data"][0]
     filters = data["filters"]
@@ -43,12 +43,7 @@ def data_wrapper(data):
     if isinstance(df, pd.DataFrame):
         res["controls"] = [f.to_json(df) for f in filters]
         res["columns"] = [
-            {
-                "title": x,
-                "dataIndex": x,
-                "key": x,
-                "render": {"action": links[x]},
-            }
+            {"title": x, "dataIndex": x, "key": x, "render": {"action": links[x]},}
             if x in links
             else {"title": x, "dataIndex": x, "key": x}
             for x in df.columns
@@ -60,13 +55,10 @@ def data_wrapper(data):
         df = df.applymap(str)
         res["dataSource"] = json.loads(
             df.to_json(
-                orient="records",
-                date_format="iso",
-                date_unit="s",
-                force_ascii=False,
+                orient="records", date_format="iso", date_unit="s", force_ascii=False,
             )
         )
-        logger.debug("res dataSource lens: " + str(len(res["dataSource"])))
+        # logger.debug("res dataSource lens: " + str(len(res["dataSource"])))
         return res
     else:
         raise TypeError("your handler should return pd.DataFrame")
@@ -123,7 +115,7 @@ class Data(object):
             m = importlib.reload(m)
             res = data_wrapper(m.main(params))
 
-            if not need_fallback:
+            if not need_fallback and params.get("name") in CACHE_LIST:
                 conn.hset("sachima_req", req_md5, req)
                 conn.hset("sachima_results", req_md5, json.dumps(res))  # 更新缓存
         return res
@@ -132,8 +124,7 @@ class Data(object):
     def writecache(self, name, value, conn=RedisClient().conn):
         logger.debug("writecache to: " + name)
         conn.rpush(
-            name,
-            json.dumps(value, indent=2, ensure_ascii=False).encode("utf-8"),
+            name, json.dumps(value, indent=2, ensure_ascii=False).encode("utf-8"),
         )
 
     @rpc
